@@ -8,7 +8,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities :classification :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.07_02';
+our $VERSION = '1.11_01';
 
 #-----------------------------------------------------------------------------
 
@@ -38,8 +38,7 @@ sub violates {
 
 1;
 
-#---------------------------------------------------------------------------
-
+__END__
 =pod
 
 =head1 NAME
@@ -66,7 +65,7 @@ Mike O'Regan <moregan@stresscafe.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2011 Andy Lester and Mike O'Regan
+Copyright (C) 2006-2013 Andy Lester and Mike O'Regan
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License 2.0.
